summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/common/render_messages_internal.h')
-rw-r--r--chrome/common/render_messages_internal.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index ec9e869..618b46d 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -736,12 +736,15 @@ IPC_BEGIN_MESSAGES(View)
ViewType::Type /* view_type */)
// Notification that renderer should run some JavaScript code.
- IPC_MESSAGE_ROUTED4(ViewMsg_ExecuteCode,
+ IPC_MESSAGE_ROUTED5(ViewMsg_ExecuteCode,
int, /* request id */
std::string, /* id of extension which runs the scripts */
bool, /* It's true if the code is JavaScript; Otherwise
the code is CSS text. */
- std::string /* code would be executed */)
+ std::string, /* code would be executed */
+ bool /* It's true if the code would be injected into all
+ frames; Otherwise the code is only injected into
+ top main frame */)
// Returns a file handle
IPC_MESSAGE_CONTROL2(ViewMsg_DatabaseOpenFileResponse,